pub enum Device {
Auto,
Cpu {
threads: usize,
},
Cuda(usize),
Metal,
Ane,
}Expand description
Where the model runs.
Variants
Auto
The first CUDA GPU when there is one and this build has CUDA, the CPU otherwise.
Cpu
The CPU, on threads threads, or every core for 0.
Cuda(usize)
A CUDA GPU by ordinal.
Metal
The Apple GPU. Arrives with M4.
Ane
The Apple Neural Engine. Arrives with M4.